package com.abi.qms.platform.service;


import com.abi.qms.platform.dao.entity.UserInfo;
import com.abi.qms.platform.dto.req.*;
import com.abi.qms.platform.dto.res.GetUserInfoRes;
import com.abi.qms.platform.dto.res.ListUserRes;
import com.abi.task.common.api.base.BaseResponse;

import java.util.List;

/**
 * <p>
 * 用户管理
 * </p>
 *
 * @author Andy.Tan
 */
public interface UserManagerService {

    /**
     * 登录
     * @param req
     * @return
     */
    BaseResponse login(LoginReq req);

    /**
     * 创建用户
     * @param createUserReq
     * @return
     * @throws Exception
     */
    BaseResponse createUser(CreateUserReq createUserReq) throws Exception;

    /**
     * 更新用户
     * @param updateUserReq
     * @throws Exception
     */
    BaseResponse updateUser(UpdateUserReq updateUserReq) throws Exception;

    /**
     * 根据id查询单个用户信息
     * @return
     * @throws Exception
     */
    GetUserInfoRes getUserInfo(Long userInfoId) throws Exception;

    /**
     * 分页查询用户列表
     * @param listUserReq
     * @return
     * @throws Exception
     */
    ListUserRes listUser(ListUserReq listUserReq) throws Exception;

    /**
     * 启用/停用用户
     */
    void enableUser(Long userInfoId) throws Exception;

    /**
     * 批量启用/停用用户
     * @param req
     * @throws Exception
     */
    void batchEnableUser(BatchEnableUserReq req)throws Exception;

    /**
     *重置密码
     * @param req
     * @return
     */
    void resetPassword(ResetPasswordReq req);

    /**
     * 修改密码
     * @return
     */
    BaseResponse updatePassword(UpdatePasswordReq req);

    /**
     * token校验
     * @param req
     * @return
     */
    UserInfo validateToken(TokenReq req);
}
